#
# spec file for package python-minidb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname minidb
%bcond_without  test
Name:           python-minidb
Version:        2.0.8
Release:        1.1
Summary:        SQLite3-based store for Python objects
License:        ISC
Group:          Development/Languages/Python
URL:            https://github.com/thp/minidb
Source:         https://github.com/thp/%{modname}/archive/refs/tags/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  python3-testsuite
%endif
%python_subpackages

%description
Minidb 2 allows you to store Python objects in a SQLite 3 database.

%prep
%autosetup -p1 -n minidb-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest -v
%endif

%files %{python_files}
%doc README.md
%{python_sitelib}/minidb.py*
%{python_sitelib}/minidb-%{version}.dist-info
%pycache_only %{python_sitelib}/__pycache__/minidb*.py*

%changelog
* Wed May  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.8:
  * fix flake8 errors
  * add python 3.12 support
  * drop python2
  * read sqlite result before releasing lock
  * switch to PEP517 build
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.0.7
  Test against Python 3.10
  YAML syntax and me
  Only pass special keyword args to model __init__
  Add delete_all() and count_rows()
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to  minidb 2.0.6
  * Add vacuum_on_close option and Store.vacuum()
* Thu Sep  9 2021 Matej Cepl <mcepl@suse.com>
- Use GitHub tarball (for tests and README.md).
* Wed Sep  1 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.0.5
  * Clean up things and set up CI (#16)
  * Don't use ported_eq function
- Drop patches for issues fixed upstream
  * no_ported_eq.patch
- Rename README to README.md in %%files section
* Tue Mar 16 2021 Matej Cepl <mcepl@suse.com>
- Update to 2.0.4:
  - switch to pytest
- Rename 0001-switch-to-pytest.patch to no_ported_eq.patch as the
  previous patch was upstreamed, and now is just a small cleanup
  (gh#thp/minidb#15).
* Fri Mar 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.0.3
- Add 0001-switch-to-pytest.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Sep  9 2017 jengelh@inai.de
- Fix grammar problems in %%description for initial submit.
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
